==> u61-0.2.2.tar.gz: u61-0.2.2/src/history.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   history.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: This is a small utility class to keep a track of what
 *              happened to each player since its last game session started.
 *              This is usefull in a network game for the server to be able
 *              to send to the new clients a complete history of what
 *              happened to each player.
 */

#ifndef INC_U61_HISTORY
#define INC_U61_HISTORY

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>

#include "event.h"

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_History
{ 
 public:
  U61_History();

  void reset();

  void clear();
  void put(U61_Event evt);
  int size();
  U61_Event get(int i);
  bool playing();
 protected:   
  vector<U61_Event> events;
  bool state;

  void loose(U61_Event *evt);
  void start_stop();
  void kill();
};

#endif

==> u61-0.4.0.tar.gz: u61-0.4.0/src/history.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   history.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: This is a small utility class to keep a track of what
 *              happened to each player since its last game session started.
 *              This is usefull in a network game for the server to be able
 *              to send to the new clients a complete history of what
 *              happened to each player.
 */

#ifndef INC_U61_HISTORY
#define INC_U61_HISTORY

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>

#include "event.h"

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_History
{ 
 public:
  U61_History();

  void reset();

  void clear();
  void put(U61_Event evt);
  int size();
  U61_Event get(int i);
  bool playing();
 protected:   
  std::vector<U61_Event> events;
  bool state;

  void loose(U61_Event *evt);
  void start_stop();
  void kill();
};

#endif
